@@ -25,7 +25,7 @@ in a web interface.
 
 This file implement some functions to manage requests/reports on WebScripts."""
 
-__version__ = "0.0.2"
+__version__ = "0.1.0"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -59,6 +59,7 @@ from typing import Tuple, List, TypeVar
 from os import environ, path, replace
 from collections.abc import Iterator
 from collections import namedtuple
+from html import escape
 import json
 import csv
 
@@ -86,24 +87,39 @@ DIRECTORY = path.join(
 )
 
 
+def anti_XSS(named_tuple: namedtuple) -> namedtuple:
+
+    """This function returns a namedtuple without HTML special characters."""
+
+    new = {}
+    for attribut, value in named_tuple._asdict().items():
+        new[attribut] = escape(value)
+    return named_tuple.__class__(**new)
+
+
 def get_requests() -> Iterator[Request]:
 
     """This function build Uploads from database."""
 
     yield from map(
-        Request._make, csv.reader(open(path.join(DIRECTORY, FILE), "r", newline=""), quoting=csv.QUOTE_ALL)
+        Request._make,
+        csv.reader(
+            open(path.join(DIRECTORY, FILE), "r", newline=""), quoting=csv.QUOTE_ALL
+        ),
     )
 
+
 def get_request(id_: str) -> Request:
 
     """This function return a specific request."""
 
     for request in get_requests():
         if request.ID == id_:
-            return request
+            return anti_XSS(request)
 
     raise ValueError("This request ID doesn't exists.")
 
+
 def delete_request(id_: str) -> Request:
 
     """This function rewrite the request database without the specified request."""
@@ -118,10 +134,10 @@ def delete_request(id_: str) -> Request:
             if request.ID == id_:
                 deleted_request = request
             else:
-                csvwriter.writerow(request)
+                csvwriter.writerow(anti_XSS(request))
 
     if deleted_request is None:
         raise ValueError("This request ID doesn't exists.")
 
     replace(filename, path.join(DIRECTORY, FILE))
-    return deleted_request
\ No newline at end of file
+    return anti_XSS(deleted_request)
