@@ -25,7 +25,7 @@ in a web interface.
 
 This file prints a HTML link to download a file."""
 
-__version__ = "0.0.1"
+__version__ = "0.1.0"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -49,6 +49,8 @@ __copyright__ = copyright
 __all__ = []
 
 from modules.uploads_management import read_file
+from urllib.parse import quote
+import html
 import sys
 
 
@@ -66,11 +68,11 @@ def main() -> None:
     try:
         data = read_file(filename)
     except Exception as e:
-        print(f"{e.__class__.__name__}: {e}")
+        print(html.escape(f"{e.__class__.__name__}: {e}"))
         sys.exit(127)
 
     print(
-        f'<a href="data:application/octet-stream;base64, {data}" download="{filename}">Click here to download {filename}</a>'
+        f'<a href="data:application/octet-stream;base64, {data}" download="{quote(filename)}">Click here to download {html.escape(filename)}</a>'
     )
 
 
